@@ -12,8 +12,9 @@ class JsrunLauncher(MultipleLauncher):
 
     def __init__(self, config: Optional[JobExecutorConfig] = None):
         """
-        Initializes this launcher using an optional configuration.
-
-        :param config: An optional configuration.
+        Parameters
+        ----------
+        config
+            An optional configuration.
         """
         super().__init__(Path(__file__).parent / 'scripts' / 'jsrun_launch.sh', config)
